#[non_exhaustive]pub struct CreateWorkloadOperationMetadata {
pub create_time: Option<Timestamp>,
pub display_name: String,
pub parent: String,
pub compliance_regime: ComplianceRegime,
/* private fields */
}Expand description
Operation metadata to give request details of CreateWorkload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.create_time: Option<Timestamp>Optional. Time when the operation was created.
display_name: StringOptional. The display name of the workload.
parent: StringOptional. The parent of the workload.
compliance_regime: ComplianceRegimeOptional. Compliance controls that should be applied to the resources managed by the workload.
Implementations
Sourceimpl CreateWorkloadOperationMetadata
impl CreateWorkloadOperationMetadata
pub fn new() -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = CreateWorkloadOperationMetadata::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
ⓘ
use wkt::Timestamp;
let x = CreateWorkloadOperationMetadata::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = CreateWorkloadOperationMetadata::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_display_name<T: Into<String>>(self, v: T) -> Self
pub fn set_display_name<T: Into<String>>(self, v: T) -> Self
Sets the value of display_name.
Example
ⓘ
let x = CreateWorkloadOperationMetadata::new().set_display_name("example");Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_compliance_regime<T: Into<ComplianceRegime>>(self, v: T) -> Self
pub fn set_compliance_regime<T: Into<ComplianceRegime>>(self, v: T) -> Self
Sets the value of compliance_regime.
Example
ⓘ
use google_cloud_assuredworkloads_v1::model::workload::ComplianceRegime;
let x0 = CreateWorkloadOperationMetadata::new().set_compliance_regime(ComplianceRegime::Il4);
let x1 = CreateWorkloadOperationMetadata::new().set_compliance_regime(ComplianceRegime::Cjis);
let x2 = CreateWorkloadOperationMetadata::new().set_compliance_regime(ComplianceRegime::FedrampHigh);Trait Implementations
Sourceimpl Clone for CreateWorkloadOperationMetadata
impl Clone for CreateWorkloadOperationMetadata
Sourcefn clone(&self) -> CreateWorkloadOperationMetadata
fn clone(&self) -> CreateWorkloadOperationMetadata
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CreateWorkloadOperationMetadata
impl Default for CreateWorkloadOperationMetadata
Sourcefn default() -> CreateWorkloadOperationMetadata
fn default() -> CreateWorkloadOperationMetadata
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for CreateWorkloadOperationMetadata
impl PartialEq for CreateWorkloadOperationMetadata
Sourcefn eq(&self, other: &CreateWorkloadOperationMetadata) -> bool
fn eq(&self, other: &CreateWorkloadOperationMetadata) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CreateWorkloadOperationMetadata