#[non_exhaustive]pub struct CreateWorkloadRequest {
pub parent: String,
pub workload: Option<Workload>,
pub external_id: String,
/* private fields */
}Expand description
Request for creating a workload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the new Workload’s parent.
Must be of the form organizations/{org_id}/locations/{location_id}.
workload: Option<Workload>Required. Assured Workload to create
external_id: StringOptional. A identifier associated with the workload and underlying projects which allows for the break down of billing costs for a workload. The value provided for the identifier will add a label to the workload and contained projects with the identifier as the value.
Implementations
Sourceimpl CreateWorkloadRequest
impl CreateWorkloadRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_workload<T>(self, v: T) -> Self
pub fn set_workload<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_workload<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_workload<T>(self, v: Option<T>) -> Self
Sourcepub fn set_external_id<T: Into<String>>(self, v: T) -> Self
pub fn set_external_id<T: Into<String>>(self, v: T) -> Self
Sets the value of external_id.
Example
ⓘ
let x = CreateWorkloadRequest::new().set_external_id("example");Trait Implementations
Sourceimpl Clone for CreateWorkloadRequest
impl Clone for CreateWorkloadRequest
Sourcefn clone(&self) -> CreateWorkloadRequest
fn clone(&self) -> CreateWorkloadRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CreateWorkloadRequest
impl Debug for CreateWorkloadRequest
Sourceimpl Default for CreateWorkloadRequest
impl Default for CreateWorkloadRequest
Sourcefn default() -> CreateWorkloadRequest
fn default() -> CreateWorkloadRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for CreateWorkloadRequest
impl Message for CreateWorkloadRequest
Sourceimpl PartialEq for CreateWorkloadRequest
impl PartialEq for CreateWorkloadRequest
impl StructuralPartialEq for CreateWorkloadRequest