#[non_exhaustive]pub struct DeleteWorkloadRequest {
pub name: String,
pub etag: String,
/* private fields */
}Expand description
Request for deleting a Workload.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name field is used to identify the workload.
Format:
organizations/{org_id}/locations/{location_id}/workloads/{workload_id}
etag: StringOptional. The etag of the workload. If this is provided, it must match the server’s etag.
Implementations