#[non_exhaustive]pub struct ListViolationsRequest {
pub parent: String,
pub interval: Option<TimeWindow>,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request for fetching violations in an organization.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The Workload name.
Format organizations/{org_id}/locations/{location}/workloads/{workload}.
interval: Option<TimeWindow>Optional. Specifies the time window for retrieving active Violations. When specified, retrieves Violations that were active between start_time and end_time.
page_size: i32Optional. Page size.
page_token: StringOptional. Page token returned from previous request.
filter: StringOptional. A custom filter for filtering by the Violations properties.
Implementations
Sourceimpl ListViolationsRequest
impl ListViolationsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_interval<T>(self, v: T) -> Selfwhere
T: Into<TimeWindow>,
pub fn set_interval<T>(self, v: T) -> Selfwhere
T: Into<TimeWindow>,
Sourcepub fn set_or_clear_interval<T>(self, v: Option<T>) -> Selfwhere
T: Into<TimeWindow>,
pub fn set_or_clear_interval<T>(self, v: Option<T>) -> Selfwhere
T: Into<TimeWindow>,
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListViolationsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListViolationsRequest
impl Clone for ListViolationsRequest
Sourcefn clone(&self) -> ListViolationsRequest
fn clone(&self) -> ListViolationsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListViolationsRequest
impl Debug for ListViolationsRequest
Sourceimpl Default for ListViolationsRequest
impl Default for ListViolationsRequest
Sourcefn default() -> ListViolationsRequest
fn default() -> ListViolationsRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListViolationsRequest
impl Message for ListViolationsRequest
Sourceimpl PartialEq for ListViolationsRequest
impl PartialEq for ListViolationsRequest
impl StructuralPartialEq for ListViolationsRequest