#[non_exhaustive]pub struct ListWorkloadsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
/* private fields */
}Expand description
Request for fetching workloads in an organization.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. Parent Resource to list workloads from.
Must be of the form organizations/{org_id}/locations/{location}.
page_size: i32Page size.
page_token: StringPage token returned from previous request. Page token contains context from previous request. Page token needs to be passed in the second and following requests.
filter: StringA custom filter for filtering by properties of a workload. At this time, only filtering by labels is supported.
Implementations
Sourceimpl ListWorkloadsRequest
impl ListWorkloadsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListWorkloadsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListWorkloadsRequest
impl Clone for ListWorkloadsRequest
Sourcefn clone(&self) -> ListWorkloadsRequest
fn clone(&self) -> ListWorkloadsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListWorkloadsRequest
impl Debug for ListWorkloadsRequest
Sourceimpl Default for ListWorkloadsRequest
impl Default for ListWorkloadsRequest
Sourcefn default() -> ListWorkloadsRequest
fn default() -> ListWorkloadsRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListWorkloadsRequest
impl Message for ListWorkloadsRequest
Sourceimpl PartialEq for ListWorkloadsRequest
impl PartialEq for ListWorkloadsRequest
impl StructuralPartialEq for ListWorkloadsRequest