#[non_exhaustive]pub enum Partner {
Unspecified,
LocalControlsByS3Ns,
UnknownValue(UnknownValue),
}Expand description
Supported Assured Workloads Partners.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Unknown partner regime/controls.
LocalControlsByS3Ns
S3NS regime/controls.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using Partner::value or Partner::name.
Implementations